@@ -133,6 +133,19 @@ public class CollectionUtil
     }
 
 
+    /**
+     *  Adds entries from <code>add</code> to <code>base</code> where there is not
+     *  already a mapping with the same key.
+     *
+     *  @since 1.0.14
+     */
+    public static <K,V> void putIfAbsent(Map<K,V> base, Map<K,V> add)
+    {
+        for (Map.Entry<K,V> entry : add.entrySet())
+            putIfAbsent(base, entry.getKey(), entry.getValue());
+    }
+
+
     /**
      *  Returns the first element of the passed list, <code>null</code> if
      *  the list is empty or null.
@@ -348,6 +361,44 @@ public class CollectionUtil
     }
 
 
+    /**
+     *  Compares two collections of <code>Comparable</code> elements. The two collections are
+     *  iterated, and the first not-equal <code>compareTo()</code> result is returned. If the
+     *  collections are of equal length and contain the same elements in iteration order, they
+     *  are considered equal. If they are of unequal length but contain the same elements in
+     *  iteration order, the shorter is considered less than the longer.
+     *  <p>
+     *  Note that two collections that are equal based on their intrinsic <code>equals()</code>
+     *  method, but iterate in a different order (ie, hash-based collections) are not considered
+     *  equal by this method.
+     *
+     *   @since 1.0.14
+     */
+    @SuppressWarnings("rawtypes")
+    public static int compare(Collection<? extends Comparable> c1, Collection<? extends Comparable> c2)
+    {
+        Iterator<? extends Comparable> itx1 = c1.iterator();
+        Iterator<? extends Comparable> itx2 = c2.iterator();
+
+        while (itx1.hasNext())
+        {
+            if (! itx2.hasNext())
+                return 1;
+
+            Comparable v1 = itx1.next();
+            Comparable v2 = itx2.next();
+            int cmp = v1.compareTo(v2);
+            if (cmp != 0)
+                return cmp;
+        }
+
+        if (itx2.hasNext())
+            return -1;
+        else
+            return 0;
+    }
+
+
     /**
      *  Returns the second iterable if the first is null. This is used for a null-safe
      *  for loop.
