@@ -109,6 +109,24 @@ public class TestCollectionUtil extends TestCase
     }
 
 
+    public void testPutAbsent() throws Exception
+    {
+        Map<String,String> base = new HashMap<String,String>();
+        base.put("foo", "bar");
+        base.put("baz", "bar");
+
+        Map<String,String> add = new HashMap<String,String>();
+        add.put("foo", "biff");
+        add.put("argle", "bargle");
+
+        CollectionUtil.putIfAbsent(base, add);
+        assertEquals("resulting map size", 3, base.size());
+        assertEquals("get(foo)",   "bar",    base.get("foo"));
+        assertEquals("get(baz)",   "bar",    base.get("baz"));
+        assertEquals("get(argle)", "bargle", base.get("argle"));
+    }
+
+
     public void testFirstAndLast() throws Exception
     {
         List<String> l1 = Arrays.asList("foo", "bar", "baz");
@@ -141,6 +159,35 @@ public class TestCollectionUtil extends TestCase
     }
 
 
+    public void testCompareEqualCollections() throws Exception
+    {
+        List<String> l1 = Arrays.asList("foo", "bar", "baz");
+        List<String> l2 = Arrays.asList("foo", "bar", "baz");
+
+        assertTrue(CollectionUtil.compare(l1, l2) == 0);
+    }
+
+
+    public void testCompareUnequalCollections() throws Exception
+    {
+        List<String> l1 = Arrays.asList("foo", "bar", "baz");
+        List<String> l2 = Arrays.asList("foo", "baz", "bar");
+
+        assertTrue(CollectionUtil.compare(l1, l2) < 0);
+        assertTrue(CollectionUtil.compare(l2, l1) > 0);
+    }
+
+
+    public void testCompareCollectionsOfDifferentLength() throws Exception
+    {
+        List<String> l1 = Arrays.asList("foo", "bar");
+        List<String> l2 = Arrays.asList("foo", "bar", "baz");
+
+        assertTrue(CollectionUtil.compare(l1, l2) < 0);
+        assertTrue(CollectionUtil.compare(l2, l1) > 0);
+    }
+
+
     public void testDefaultIfNull() throws Exception
     {
         Iterable<String> it1 = CollectionUtil.defaultIfNull(Arrays.asList("foo"), Arrays.asList("bar"));
